@@ -131,14 +131,12 @@ const char *jwt_alg_str(jwt_alg_t alg)
 		return "ES384";
 	case JWT_ALG_ES512:
 		return "ES512";
-#ifndef HAVE_OPENSSL
 	case JWT_ALG_PS256:
 		return "PS256";
 	case JWT_ALG_PS384:
 		return "PS384";
 	case JWT_ALG_PS512:
 		return "PS512";
-#endif
 	default:
 		return NULL;
 	}
@@ -169,14 +167,12 @@ jwt_alg_t jwt_str_alg(const char *alg)
 		return JWT_ALG_ES384;
 	else if (!strcmp(alg, "ES512"))
 		return JWT_ALG_ES512;
-#ifndef HAVE_OPENSSL
 	else if (!strcmp(alg, "PS256"))
 		return JWT_ALG_PS256;
 	else if (!strcmp(alg, "PS384"))
 		return JWT_ALG_PS384;
 	else if (!strcmp(alg, "PS512"))
 		return JWT_ALG_PS512;
-#endif
 
 	return JWT_ALG_INVAL;
 }
@@ -416,6 +412,11 @@ void *jwt_b64_decode(const char *src, int *ret_len)
 
 	*ret_len = jwt_Base64decode(buf, new);
 
+	if (*ret_len == 0) {
+		jwt_freemem(buf);
+		buf = NULL;
+	}
+
 	return buf;
 }
 
@@ -478,7 +479,8 @@ static int jwt_sign(jwt_t *jwt, char **out, unsigned int *len, const char *str,
 	case JWT_ALG_RS512:
 
 #ifndef HAVE_OPENSSL
-	/* PS */
+	/* XXX These do not work right now on OpenSSL */
+	/* RSA-PSS */
 	case JWT_ALG_PS256:
 	case JWT_ALG_PS384:
 	case JWT_ALG_PS512:
@@ -511,7 +513,8 @@ static int jwt_verify(jwt_t *jwt, const char *head, unsigned int head_len, const
 	case JWT_ALG_RS512:
 
 #ifndef HAVE_OPENSSL
-	/* PS */
+	/* XXX These do not work right now on OpenSSL */
+	/* RSA-PSS */
 	case JWT_ALG_PS256:
 	case JWT_ALG_PS384:
 	case JWT_ALG_PS512:
@@ -1096,6 +1099,25 @@ static int jwt_dump(jwt_t *jwt, char **buf, int pretty)
 	return ret;
 }
 
+char *jwt_dump_grants_str(jwt_t *jwt, int pretty)
+{
+	char *out = NULL;
+	int err;
+
+	errno = 0;
+
+	err = jwt_write_body(jwt, &out, pretty);
+
+	if (err) {
+		errno = err;
+		if (out)
+			jwt_freemem(out);
+		out = NULL;
+	}
+
+	return out;
+}
+
 int jwt_dump_fp(jwt_t *jwt, FILE *fp, int pretty)
 {
 	char *out = NULL;
@@ -1608,7 +1630,7 @@ static jwt_exception_dict_t jwt_exceptions[] = {
 
 char *jwt_exception_str(unsigned int exceptions)
 {
-	int rc;
+	int rc, i;
 	char *str = NULL;
 
 	if (exceptions == JWT_VALIDATION_SUCCESS) {
@@ -1617,7 +1639,7 @@ char *jwt_exception_str(unsigned int exceptions)
 		return str;
 	}
 
-	for (int i = 0; i < ARRAY_SIZE(jwt_exceptions); i++) {
+	for (i = 0; i < ARRAY_SIZE(jwt_exceptions); i++) {
 		if (!(jwt_exceptions[i].error & exceptions))
 			continue;
 
